<?php

namespace Drupal\ckeditor_standalone_styles\Plugin\CKEditor5Plugin;

use Drupal\ckeditor5\Plugin\CKEditor5Plugin\Style as CoreStyle;
use Drupal\ckeditor_standalone_styles\CKEditorStylesHelper;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\editor\EditorInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Extend core's Style plugin to integrate with our style definition storage.
 */
class Style extends CoreStyle implements ContainerFactoryPluginInterface {

  /**
   * Constructs a new Style plugin.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\ckeditor_standalone_styles\CKEditorStylesHelper $ckeditorStylesHelper
   *   The CKEditor Styles Helper service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, protected CKEditorStylesHelper $ckeditorStylesHelper) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('ckeditor_standalone_styles.helper')
    );
  }

  /**
   * {@inheritDoc}
   */
  public function getElementsSubset(): array {
    return array_column($this->ckeditorStylesHelper->generateStyleSetSettingsDataCkeditor5(), 'element');
  }

  /**
   * {@inheritDoc}
   */
  public function getDynamicPluginConfig(array $static_plugin_config, EditorInterface $editor): array {
    return [
      'style' => [
        'definitions' => $this->ckeditorStylesHelper->generateStyleSetSettingsDataCkeditor5(),
      ],
    ];
  }

}
